@@ -23,11 +23,8 @@
 #define	_GNOME_SCAN_H_
 
 #include <gnome-scan-init.h>
-#include <gnome-scan-param-specs.h>
 #include <gnome-scan-job.h>
-#include <gnome-scan-plugin.h>
-#include <gnome-scan-sink.h>
+#include <gnome-scan-node.h>
 #include <gnome-scan-dialog.h>
-#include <gnome-scan-acquisition-dialog.h>
 
 #endif
